@@ -11,6 +11,7 @@
 from __future__ import unicode_literals
 import pickle
 import os
+import sys
 
 import pytest
 
@@ -24,27 +25,29 @@ def rootdir():
     return path(os.path.dirname(__file__)).abspath()
 
 
+@pytest.mark.skipif(sys.version_info < (3, 6), reason="requires python3.6 or higher")
 def test_with_prefix(make_app, rootdir):
     srcdir = rootdir / 'roots' / 'test_package_prefix'
     app = make_app(srcdir=srcdir)
     app.builder.build_all()
 
-    content = pickle.loads((app.doctreedir / 'index.doctree').bytes())
+    content = pickle.loads((app.doctreedir / 'index.doctree').read_bytes())
 
     assert isinstance(content[4], addnodes.desc)
-    assert content[4].astext() == '+package.funcx\n\nReturns x'
+    assert content[4].astext() == '+package.func(x)\n\nReturns x'
 
 
+@pytest.mark.skipif(sys.version_info < (3, 6), reason="requires python3.6 or higher")
 def test_without_prefix(make_app, rootdir):
     srcdir = rootdir / 'roots' / 'test_package_prefix'
     confdict = { 'matlab_keep_package_prefix' : False }
     app = make_app(srcdir=srcdir, confoverrides=confdict)
     app.builder.build_all()
 
-    content = pickle.loads((app.doctreedir / 'index.doctree').bytes())
+    content = pickle.loads((app.doctreedir / 'index.doctree').read_bytes())
 
     assert isinstance(content[4], addnodes.desc)
-    assert content[4].astext() == 'package.funcx\n\nReturns x'
+    assert content[4].astext() == 'package.func(x)\n\nReturns x'
 
 
 if __name__ == '__main__':
